==> hvcc-0.4.0.tar.gz: hvcc-0.4.0/hvcc/generators/ir2c/ControlSlice.py <==
# Copyright (C) 2014-2018 Enzien Audio, Ltd.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from .HeavyObject import HeavyObject


class ControlSlice(HeavyObject):

    c_struct = "ControlSlice"
    preamble = "cSlice"

    @classmethod
    def get_C_header_set(clazz):
        return {"HvControlSlice.h"}

    @classmethod
    def get_C_file_set(clazz):
        return {"HvControlSlice.h", "HvControlSlice.c"}

    @classmethod
    def get_C_init(clazz, obj_type, obj_id, args):
        return [
            "cSlice_init(&cSlice_{0}, {1}, {2});".format(
                obj_id,
                int(args["index"]),
                int(args["length"]))]

    @classmethod
    def get_C_free(clazz, obj_type, obj_id, args):
        return []  # nothing to free

    @classmethod
    def get_C_onMessage(clazz, obj_type, obj_id, inlet_index, args):
        return [
            "cSlice_onMessage(_c, &Context(_c)->cSlice_{0}, {1}, m, &cSlice_{0}_sendMessage);".format(
                obj_id,
                inlet_index)
        ]

==> hvcc_0.13.3.orig.tar.gz: hvcc-0.13.3/hvcc/generators/ir2c/ControlSlice.py <==
# Copyright (C) 2014-2018 Enzien Audio, Ltd.
# Copyright (C) 2023-2024 Wasted Audio
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from typing import Dict, List

from .HeavyObject import HeavyObject


class ControlSlice(HeavyObject):

    c_struct = "ControlSlice"
    preamble = "cSlice"

    @classmethod
    def get_C_header_set(cls) -> set:
        return {"HvControlSlice.h"}

    @classmethod
    def get_C_file_set(cls) -> set:
        return {"HvControlSlice.h", "HvControlSlice.c"}

    @classmethod
    def get_C_init(cls, obj_type: str, obj_id: str, args: Dict) -> List[str]:
        return [
            "cSlice_init(&cSlice_{0}, {1}, {2});".format(
                obj_id,
                int(args["index"]),
                int(args["length"]))]

    @classmethod
    def get_C_free(cls, obj_type: str, obj_id: str, args: Dict) -> List[str]:
        return []  # nothing to free

    @classmethod
    def get_C_onMessage(cls, obj_type: str, obj_id: str, inlet_index: int, args: Dict) -> List[str]:
        return [
            f"cSlice_onMessage(_c, &Context(_c)->cSlice_{obj_id}, {inlet_index}, m, &cSlice_{obj_id}_sendMessage);"
        ]
